==> redquicklib-1.485.0.tgz: package/lib/telephoneinput.js <==
import React, { Component } from 'react';
const reduce = require('lodash.reduce');
const first = require('lodash.first');
const tail = require('lodash.tail');

import countryData from './country_data';
const allCountriesObject = countryData.allCountriesObject;

function reverseString(str) {
  str = (str || '').toString()
  // Step 1. Use the split() method to return a new array
  var splitString = str.split(""); // var splitString = "hello".split("");
  // ["h", "e", "l", "l", "o"]

  // Step 2. Use the reverse() method to reverse the new created array
  var reverseArray = splitString.reverse(); // var reverseArray = ["h", "e", "l", "l", "o"].reverse();
  // ["o", "l", "l", "e", "h"]

  // Step 3. Use the join() method to join all elements of the array into a string
  var joinArray = reverseArray.join(""); // var joinArray = ["o", "l", "l", "e", "h"].join("");
  // "olleh"

  //Step 4. Return the reversed string
  return joinArray; // "olleh"
}
var tele = {
  getCountryName: (me, phoneNumber, formatKey) => {
    return tele.guessSelectedCountry(me, phoneNumber, formatKey);
  },
  socialSecurity: (text, pattern) => {
    text = text.substr(0, 16);
    pattern = pattern || '... .. ....';
    if (!text || text.length === 0) {
      return '';
    }

    if ((text && text.length < 2) || !pattern) {
      return `${text}`;
    }

    const formattedObject = reduce(pattern, (acc, character) => {
      if (acc.remainingText.length === 0) {
        return acc;
      }

      if (character !== '.') {
        return {
          formattedText: acc.formattedText + character,
          remainingText: acc.remainingText,
        };
      }

      return {
        formattedText: acc.formattedText + first(acc.remainingText),
        remainingText: tail(acc.remainingText),
      };
    }, { formattedText: '', remainingText: text.split('') });
    return formattedObject.formattedText + formattedObject.remainingText.join('');
  },
  date: (text, pattern) => {
    text = text.substr(0, 16);
    pattern = pattern || '..../../..';
    if (!text || text.length === 0) {
      return '';
    }

    if ((text && text.length < 2) || !pattern) {
      return `${text}`;
    }

    const formattedObject = reduce(pattern, (acc, character) => {
      if (acc.remainingText.length === 0) {
        return acc;
      }

      if (character !== '.') {
        return {
          formattedText: acc.formattedText + character,
          remainingText: acc.remainingText,
        };
      }

      return {
        formattedText: acc.formattedText + first(acc.remainingText),
        remainingText: tail(acc.remainingText),
      };
    }, { formattedText: '', remainingText: text.split('') });
    return formattedObject.formattedText + formattedObject.remainingText.join('');
  },
  creditCard: (text, pattern) => {
    text = text.substr(0, 16);
    pattern = pattern || '.... .... .... ....';
    if (!text || text.length === 0) {
      return '';
    }

    if ((text && text.length < 2) || !pattern) {
      return `${text}`;
    }

    const formattedObject = reduce(pattern, (acc, character) => {
      if (acc.remainingText.length === 0) {
        return acc;
      }

      if (character !== '.') {
        return {
          formattedText: acc.formattedText + character,
          remainingText: acc.remainingText,
        };
      }

      return {
        formattedText: acc.formattedText + first(acc.remainingText),
        remainingText: tail(acc.remainingText),
      };
    }, { formattedText: '', remainingText: text.split('') });
    return formattedObject.formattedText + formattedObject.remainingText.join('');
  },
  removeNonNumbers: (val, and, nozero) => {
    and = and || '';
    var numbers = '0123456789' + and;
    if (nozero) {
      val = (val || '').toString();
    }
    else
      val = (val || '0').toString();
    return val.split('').filter(x => numbers.indexOf(x) !== -1).join('');
  },
  currency: (text, decimals) => {
    try {
      text = Number.parseInt(tele.removeNonNumbers(text)).toString();
    } catch (e) { }
    text = reverseString(text || '');
    text = tele.removeNonNumbers(text)
    var pattern = '--.----------';
    if (!text || text.length === 0) {
      return '';
    }

    // if ((text && text.length < 2) || !pattern) {
    //   return `${text}`;
    // }

    const formattedObject = reduce(pattern, (acc, character) => {
      if (acc.remainingText.length === 0) {
        return acc;
      }

      if (character !== '-') {
        return {
          formattedText: acc.formattedText + character,
          remainingText: acc.remainingText,
        };
      }

      return {
        formattedText: acc.formattedText + first(acc.remainingText),
        remainingText: tail(acc.remainingText),
      };
    }, { formattedText: '', remainingText: text.split('') });
    var result = reverseString(formattedObject.formattedText + formattedObject.remainingText.join(''));
    if (result.length == 0) {
      result = '0.00';
    }
    else if (result.length === 1) {
      result = '0.0' + result;
    }
    else if (result.length === 2) {
      result = '0.' + result;
    }
    return result;
  },
  formatNumber: (text, pattern) => {
    if (!text || text.length === 0) {
      return '+';
    }
    if (text[0] === '+') {
      text = text.substr(1);
    }

    if ((text && text.length < 2) || !pattern) {
      return `+${text}`;
    }

    const formattedObject = reduce(pattern, (acc, character) => {
      if (acc.remainingText.length === 0) {
        return acc;
      }

      if (character !== '.') {
        return {
          formattedText: acc.formattedText + character,
          remainingText: acc.remainingText,
        };
      }

      return {
        formattedText: acc.formattedText + first(acc.remainingText),
        remainingText: tail(acc.remainingText),
      };
    }, { formattedText: '', remainingText: text.split('') });
    return formattedObject.formattedText + formattedObject.remainingText.join('');
  },
  getFormattedPhoneNumber: (phoneNumber) => {
    var choice = null;
    phoneNumber = phoneNumber || '';
    for (let i = 0; i < allCountriesObject.length; i++) {
      if (phoneNumber.startsWith('+' + allCountriesObject[i].dialCode) ||
        phoneNumber.startsWith(allCountriesObject[i].dialCode)) {
        const isoCcode = allCountriesObject[i].iso2.toUpperCase();
        choice = { best_choice: isoCcode, index: i };
        break;
      }
    }
    if (choice) {
      var index = choice.index;
      if (allCountriesObject[index]) {
        const formattedNumber = tele.formatNumber(phoneNumber.replace(/\D/g, ''), allCountriesObject[index].format);
        return formattedNumber;
      }
    }
    return null;
  },
  guessSelectedCountry: (me, phoneNumber, formatKey) => {
    for (let i = 0; i < allCountriesObject.length; i++) {
      if (phoneNumber.startsWith('+' + allCountriesObject[i].dialCode) ||
        allCountriesObject[i].dialCode === phoneNumber) {
        const isoCcode = allCountriesObject[i].iso2.toUpperCase();
        const formattedNumber = tele.formatNumber(phoneNumber.replace(/\D/g, ''), allCountriesObject[i].format);
        var ops = {};
        if (formatKey) {
          ops = { [formatKey]: formattedNumber };
        }
        me.setState(Object.assign({ best_choice: isoCcode, index: i, formattedNumber }, ops));
        break;
      } else {
        var ops = {};
        if (phoneNumber.length < 4) {

          if (formatKey) {
            ops = { [formatKey]: phoneNumber };
          }
          me.setState(Object.assign({ iso_code: '', formattedNumber: phoneNumber }, ops));
        } else {
          if (me.state.index !== undefined) {

            const formattedNumber = tele.formatNumber(phoneNumber.replace(/\D/g, ''),
              allCountriesObject[me.state.index].format);

            if (formatKey) {
              ops = { [formatKey]: formattedNumber };
            }
            me.setState(Object.assign({
              iso_code: me.state.best_choice,
              formattedNumber,
            }, ops));
          }
        }
      }
    }
  }
}

export default tele;

==> redquicklib-1.500.0.tgz: package/lib/telephoneinput.js <==
import React, { Component } from 'react';
const reduce = require('lodash.reduce');
const first = require('lodash.first');
const tail = require('lodash.tail');

import countryData from './country_data';
const allCountriesObject = countryData.allCountriesObject;

function reverseString(str) {
  str = (str || '').toString()
  // Step 1. Use the split() method to return a new array
  var splitString = str.split(""); // var splitString = "hello".split("");
  // ["h", "e", "l", "l", "o"]

  // Step 2. Use the reverse() method to reverse the new created array
  var reverseArray = splitString.reverse(); // var reverseArray = ["h", "e", "l", "l", "o"].reverse();
  // ["o", "l", "l", "e", "h"]

  // Step 3. Use the join() method to join all elements of the array into a string
  var joinArray = reverseArray.join(""); // var joinArray = ["o", "l", "l", "e", "h"].join("");
  // "olleh"

  //Step 4. Return the reversed string
  return joinArray; // "olleh"
}
var tele = {
  getCountryName: (me, phoneNumber, formatKey) => {
    return tele.guessSelectedCountry(me, phoneNumber, formatKey);
  },
  socialSecurity: (text, pattern) => {
    text = text.substr(0, 16);
    pattern = pattern || '... .. ....';
    if (!text || text.length === 0) {
      return '';
    }

    if ((text && text.length < 2) || !pattern) {
      return `${text}`;
    }

    const formattedObject = reduce(pattern, (acc, character) => {
      if (acc.remainingText.length === 0) {
        return acc;
      }

      if (character !== '.') {
        return {
          formattedText: acc.formattedText + character,
          remainingText: acc.remainingText,
        };
      }

      return {
        formattedText: acc.formattedText + first(acc.remainingText),
        remainingText: tail(acc.remainingText),
      };
    }, { formattedText: '', remainingText: text.split('') });
    return formattedObject.formattedText + formattedObject.remainingText.join('');
  },
  date: (text, pattern) => {
    text = text.substr(0, 16);
    pattern = pattern || '....-..-..';
    if (!text || text.length === 0) {
      return '';
    }

    if ((text && text.length < 2) || !pattern) {
      return `${text}`;
    }

    const formattedObject = reduce(pattern, (acc, character) => {
      if (acc.remainingText.length === 0) {
        return acc;
      }

      if (character !== '.') {
        return {
          formattedText: acc.formattedText + character,
          remainingText: acc.remainingText,
        };
      }

      return {
        formattedText: acc.formattedText + first(acc.remainingText),
        remainingText: tail(acc.remainingText),
      };
    }, { formattedText: '', remainingText: text.split('') });
    return formattedObject.formattedText + formattedObject.remainingText.join('');
  },
  creditCard: (text, pattern) => {
    text = text.substr(0, 16);
    pattern = pattern || '.... .... .... ....';
    if (!text || text.length === 0) {
      return '';
    }

    if ((text && text.length < 2) || !pattern) {
      return `${text}`;
    }

    const formattedObject = reduce(pattern, (acc, character) => {
      if (acc.remainingText.length === 0) {
        return acc;
      }

      if (character !== '.') {
        return {
          formattedText: acc.formattedText + character,
          remainingText: acc.remainingText,
        };
      }

      return {
        formattedText: acc.formattedText + first(acc.remainingText),
        remainingText: tail(acc.remainingText),
      };
    }, { formattedText: '', remainingText: text.split('') });
    return formattedObject.formattedText + formattedObject.remainingText.join('');
  },
  removeNonNumbers: (val, and, nozero) => {
    and = and || '';
    var numbers = '0123456789' + and;
    if (nozero) {
      val = (val || '').toString();
    }
    else
      val = (val || '0').toString();
    return val.split('').filter(x => numbers.indexOf(x) !== -1).join('');
  },
  currency: (text, decimals) => {
    try {
      text = Number.parseInt(tele.removeNonNumbers(text)).toString();
    } catch (e) { }
    text = reverseString(text || '');
    text = tele.removeNonNumbers(text)
    var pattern = '--.----------';
    if (!text || text.length === 0) {
      return '';
    }

    // if ((text && text.length < 2) || !pattern) {
    //   return `${text}`;
    // }

    const formattedObject = reduce(pattern, (acc, character) => {
      if (acc.remainingText.length === 0) {
        return acc;
      }

      if (character !== '-') {
        return {
          formattedText: acc.formattedText + character,
          remainingText: acc.remainingText,
        };
      }

      return {
        formattedText: acc.formattedText + first(acc.remainingText),
        remainingText: tail(acc.remainingText),
      };
    }, { formattedText: '', remainingText: text.split('') });
    var result = reverseString(formattedObject.formattedText + formattedObject.remainingText.join(''));
    if (result.length == 0) {
      result = '0.00';
    }
    else if (result.length === 1) {
      result = '0.0' + result;
    }
    else if (result.length === 2) {
      result = '0.' + result;
    }
    return result;
  },
  formatNumber: (text, pattern) => {
    if (!text || text.length === 0) {
      return '+';
    }
    if (text[0] === '+') {
      text = text.substr(1);
    }

    if ((text && text.length < 2) || !pattern) {
      return `+${text}`;
    }

    const formattedObject = reduce(pattern, (acc, character) => {
      if (acc.remainingText.length === 0) {
        return acc;
      }

      if (character !== '.') {
        return {
          formattedText: acc.formattedText + character,
          remainingText: acc.remainingText,
        };
      }

      return {
        formattedText: acc.formattedText + first(acc.remainingText),
        remainingText: tail(acc.remainingText),
      };
    }, { formattedText: '', remainingText: text.split('') });
    return formattedObject.formattedText + formattedObject.remainingText.join('');
  },
  getFormattedPhoneNumber: (phoneNumber) => {
    var choice = null;
    phoneNumber = phoneNumber || '';
    for (let i = 0; i < allCountriesObject.length; i++) {
      if (phoneNumber.startsWith('+' + allCountriesObject[i].dialCode) ||
        phoneNumber.startsWith(allCountriesObject[i].dialCode)) {
        const isoCcode = allCountriesObject[i].iso2.toUpperCase();
        choice = { best_choice: isoCcode, index: i };
        break;
      }
    }
    if (choice) {
      var index = choice.index;
      if (allCountriesObject[index]) {
        const formattedNumber = tele.formatNumber(phoneNumber.replace(/\D/g, ''), allCountriesObject[index].format);
        return formattedNumber;
      }
    }
    return null;
  },
  guessSelectedCountry: (me, phoneNumber, formatKey) => {
    for (let i = 0; i < allCountriesObject.length; i++) {
      if (phoneNumber.startsWith('+' + allCountriesObject[i].dialCode) ||
        allCountriesObject[i].dialCode === phoneNumber) {
        const isoCcode = allCountriesObject[i].iso2.toUpperCase();
        const formattedNumber = tele.formatNumber(phoneNumber.replace(/\D/g, ''), allCountriesObject[i].format);
        var ops = {};
        if (formatKey) {
          ops = { [formatKey]: formattedNumber };
        }
        me.setState(Object.assign({ best_choice: isoCcode, index: i, formattedNumber }, ops));
        break;
      } else {
        var ops = {};
        if (phoneNumber.length < 4) {

          if (formatKey) {
            ops = { [formatKey]: phoneNumber };
          }
          me.setState(Object.assign({ iso_code: '', formattedNumber: phoneNumber }, ops));
        } else {
          if (me.state.index !== undefined) {

            const formattedNumber = tele.formatNumber(phoneNumber.replace(/\D/g, ''),
              allCountriesObject[me.state.index].format);

            if (formatKey) {
              ops = { [formatKey]: formattedNumber };
            }
            me.setState(Object.assign({
              iso_code: me.state.best_choice,
              formattedNumber,
            }, ops));
          }
        }
      }
    }
  }
}

export default tele;
